@@ -303,8 +303,8 @@ class CompleteMultipartUploadResult:
         self._etag = findtext(element, "ETag")
         if self._etag:
             self._etag = self._etag.replace('"', "")
-        self._version_id = response.getheader("x-amz-version-id")
-        self._http_headers = response.getheaders()
+        self._version_id = response.headers.get("x-amz-version-id")
+        self._http_headers = response.headers
 
     @property
     def bucket_name(self):
